==> rally-openstack-2.1.0.tar.gz: rally-openstack-2.1.0/rally_openstack/task/contexts/quotas/designate_quotas.py <==
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


class DesignateQuotas(object):
    """Management of Designate quotas."""

    QUOTAS_SCHEMA = {
        "type": "object",
        "additionalProperties": False,
        "properties": {
            "api_export_size": {
                "type": "integer",
                "minimum": 1
            },
            "zones": {
                "type": "integer",
                "minimum": 1
            },
            "zones_recordsets": {
                "type": "integer",
                "minimum": 1
            },
            "zones_records": {
                "type": "integer",
                "minimum": 1
            },
            "recordset_records": {
                "type": "integer",
                "minimum": 1
            },
        }
    }

    def __init__(self, clients):
        self.clients = clients

    def update(self, tenant_id, **kwargs):
        self.clients.designate().quotas.update(tenant_id, kwargs)

    def delete(self, tenant_id):
        self.clients.designate().quotas.reset(tenant_id)

    def get(self, tenant_id):
        # NOTE(andreykurilin): we have broken designate jobs, so I can't check
        #   that this method is right :(
        response = self.clients.designate().quotas.get(tenant_id)
        return dict([(k, response.get(k))
                     for k in self.QUOTAS_SCHEMA["properties"]])

==> rally-openstack-2.3.0.tar.gz: rally-openstack-2.3.0/rally_openstack/task/contexts/quotas/designate_quotas.py <==
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


class DesignateQuotas(object):
    """Management of Designate quotas."""

    QUOTAS_SCHEMA = {
        "type": "object",
        "additionalProperties": False,
        "properties": {
            "api_export_size": {
                "type": "integer",
                "minimum": 1
            },
            "zones": {
                "type": "integer",
                "minimum": 1
            },
            "zone_recordsets": {
                "type": "integer",
                "minimum": 1
            },
            "zone_records": {
                "type": "integer",
                "minimum": 1
            },
            "recordset_records": {
                "type": "integer",
                "minimum": 1
            },
        }
    }

    def __init__(self, clients):
        self.clients = clients

    def update(self, tenant_id, **kwargs):
        self.clients.designate().quotas.update(tenant_id, kwargs)

    def delete(self, tenant_id):
        self.clients.designate().quotas.reset(tenant_id)

    def get(self, tenant_id):
        # NOTE(andreykurilin): we have broken designate jobs, so I can't check
        #   that this method is right :(
        response = self.clients.designate().quotas.get(tenant_id)
        return dict([(k, response.get(k))
                     for k in self.QUOTAS_SCHEMA["properties"]])
